//----------------------------------------------------------------------
// File:			ALTSbasicStat.cpp
// Programmer:		David Mount
// Description:		Basic stats
// Last modified:	06/17/2015 (Version 1.0)
//----------------------------------------------------------------------
// Copyright (c) 2015 University of Maryland and David Mount.  All
// Rights Reserved.
// 
// This software and related documentation is part of the Approximate
// Least-Trimmed Squares (ALTS) software.  This software is provided
// under the provisions of the GNU Public License (GPL). See the file
// ReadMe.txt for further information.
// 
// The University of Maryland (U.M.) and the authors make no
// representations about the suitability or fitness of this software for
// any purpose.  It is provided "as is" without express or implied
// warranty.
//----------------------------------------------------------------------
// History:
//	Revision 1.0  06/17/2015
//		Initial release
//----------------------------------------------------------------------

#include "ALTSbasicStat.h"				// basis stat definitions

using namespace std;					// make std:: accessible
using namespace alts;					// make alts:: accessible

//----------------------------------------------------------------------
//	BasicStat methods
//----------------------------------------------------------------------

void BasicStat::update()				// update values
{
	meanVal = sum / n;
#ifdef ALTS_USE_BIASED_VARIANCE
	varVal = (sumSq / n) - meanVal*meanVal;
#else
	varVal = (sumSq - sum*sum/double(n))/double(n-1);
#endif
	if (varVal < 0) varVal = 0;			// variance should be positive
	dirty = false;
}

Scalar BasicStat::mean()				// mean
{
	if (dirty) update();
	return meanVal;
}
										// variance
Scalar BasicStat::variance()
{
	if (dirty) update();
	return varVal;
}
